package no.ntnu.idatt1002.demo.data.Economics;

/**
 * The Income class inherits from the Item class. The Item class additionally has a private field for an
 * enum value of IncomeCategory.
 *
 * @author Hanne-Sofie
 */
public class Income extends Item{

    private IncomeCategory category;

    /**
     * This constructor uses the super constructor to set the fields for 'amount' and 'recurring' and then sets the
     * category. A IllegalArgumentException from this constructor if the category is left blank. The description
     * field is left to the default blank string.
     *
     * @param amount The amount of the current income object as a double.
     * @param recurring True if the current income repeats at regular intervals.
     * @param category The category to which the Income belongs to, provided as a value of IncomeCategory.
     * @param date The date of the Income at format "dd.mm.yy".
     */
    public Income(double amount, boolean recurring, IncomeCategory category, String date) {
        super(amount, recurring, date);

        if(category == null) {
            throw new IllegalArgumentException("The income must belong to a category.");
        }
        this.category = category;
    }

    /**
     * This constructor uses the super constructor to set the fields for 'amount', 'description' and 'recurring'
     * and then sets the category. A IllegalArgumentException from this constructor if the category is left blank.
     * @param description A description of the income as a String.
     * @param amount The amount of the current income object as a double.
     * @param recurring True if the current income repeats at regular intervals.
     * @param category The category to which the income belongs to, provided as a value of IncomeCategory.
     * @param date The date of the Income at format "dd.mm.yy".
     */
    public Income(String description, double amount, boolean recurring, IncomeCategory category, String date) {
        super(description, amount, recurring, date);
        if(category == null) {
            throw new IllegalArgumentException("The income must belong to a category.");
        }
        this.category = category;

    }

    /**
     * The method returns the category to which the Income belongs as a value of the IncomeCategory enum.
     * @return The category to which the Income belongs to as a value of the IncomeCategory enum.
     */
    public IncomeCategory getCategory() {
        return category;
    }

    /**
     * The method sets the category of an item to a value of the Category enum class.
     * @param category The category to which the Income belongs to as a value of the IncomeCategory enum.
     */
    public void setCategory(IncomeCategory category) {
        if(category == null) {
            throw new IllegalArgumentException("The income must belong to a category.");
        }
        this.category = category;
    }



}
